import requests
import MeanStars
import os

if __name__ == "__main__":
    fname = "EEM_dwarf_UBVIJHK_colors_Teff.txt"
    url = "http://www.pas.rochester.edu/~emamajek/" + fname
    res = requests.get(url)

    assert res.status_code == 200

    txt = res.content.decode().split("\n")

    linenos = []
    # look for lines starting with #SpT:
    for j, ll in enumerate(txt):
        if ll.startswith("#SpT"):
            linenos.append(j)

    # there should be only 2 of these
    assert len(linenos) == 2

    # generate copy of file with first header uncommented
    # and everything after second header commented
    outtxt = txt[: linenos[0]]
    outtxt.append(txt[linenos[0]].strip("#"))
    outtxt += txt[linenos[0] + 1 : linenos[1] + 1]
    for j in range(linenos[1] + 1, len(txt)):
        outtxt.append("#{}".format(txt[j]))

    outfile = os.path.join(os.path.split(MeanStars.__file__)[0], fname)
    with open(outfile, "w") as f:
        for ll in outtxt:
            f.write("{}\n".format(ll))



import setuptools
import os
import re

with open("README.md", "r") as fh:
    long_description = fh.read()


with open(os.path.join("MeanStars", "__init__.py"), "r") as f:
    version_file = f.read()

version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)

if version_match:
    version_string = version_match.group(1)
else:
    raise RuntimeError("Unable to find version string.")

descstr = ("Automated property interpolation and color calculations for "
           "main sequence stars")

setuptools.setup(
    name="MeanStars",
    version=version_string,
    author="Dmitry Savransky",
    author_email="ds264@cornell.edu",
    description=descstr,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dsavransky/MeanStars",
    packages=["MeanStars"],
    package_data={"MeanStars": ["EEM_dwarf_UBVIJHK_colors_Teff.txt"]},
    install_requires=["scipy", "numpy", "astropy"],
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
)
